@@ -1,7 +1,7 @@
 import pandas as pd
 import logging
 
-from . import merge_dataframes
+from . import merge_dataframes, validate_options
 
 def merge_files(left_file: str, right_file: str, column: str, keep: str = 'none', keep_missing: str = 'none') -> pd.DataFrame:
     """
